%define expat_version           2.0.1

%define lib_major 3
%define lib_api 1
%define lib_name %mklibname dbus- %{lib_api} %{lib_major}
%define develname %mklibname -d dbus- %lib_api

%define enable_test 0
%define enable_verbose 0

Summary: D-Bus message bus
Name: dbus
Version: 1.1.20
Release: %mkrel 5
URL: http://www.freedesktop.org/Software/dbus
Source0: http://dbus.freedesktop.org/releases/dbus/%{name}-%{version}.tar.gz
Source1: doxygen_to_devhelp.xsl
# (fc) 0.20-1mdk fix start/stop order (fd.o bug #11491)
Patch0: dbus-initscript.patch
# (fc) 1.0.2-5mdv disable fatal warnings on check (fd.o bug #13270)
Patch3: dbus-1.0.2-disable_fatal_warning_on_check.patch
# (fc) 1.1.2-1mdv generate xml doc (Fedora)
Patch6: dbus-1.0.1-generate-xml-docs.patch
# (fc) 1.1.20-4mdv fix inotify monitoring to be less agressive
Patch7: dbus-1.1.20-fixmonitor.patch

License: GPLv2+ or AFL
Group: System/Servers
BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: libx11-devel
BuildRequires: expat-devel >= %{expat_version}
BuildRequires: xmlto docbook-dtd412-xml
BuildRequires: doxygen
BuildRequires: libtool
Requires(pre): rpm-helper
Requires(preun): rpm-helper
Requires(post): rpm-helper
Requires(postun): rpm-helper
Requires(post): %{lib_name} >= %{version}-%{release}
Provides: should-restart = system

%description
D-Bus is a system for sending messages between applications. It is
used both for the systemwide message bus service, and as a
per-user-login-session messaging facility.

%package -n %{lib_name}
Summary: Shared library for using D-Bus
Group: System/Libraries
Requires: dbus >= %{version}

%description -n %{lib_name}
D-Bus shared library.

%package -n %develname
Summary: Libraries and headers for D-Bus
Group: Development/C
Requires: %{name} = %{version}
Requires: %{lib_name} = %{version}
Provides: lib%{name}-1-devel = %{version}-%{release}
Provides: lib%{name}-devel = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Conflicts: %{_lib}dbus-1_0-devel
Obsoletes: %mklibname -d dbus- 1 3

%description -n %develname
Headers and static libraries for D-Bus.

%package x11
Summary: X11-requiring add-ons for D-Bus
Group: System/Servers
Requires: dbus = %{version}

%description x11
D-Bus contains some tools that require Xlib to be installed, those are
in this separate package so server systems need not install X.

%prep
%setup -q 
%patch0 -p1 -b .initscript
#only disable in cooker to detect buggy programs
#patch3 -p1 -b .disable_fatal_warning_on_check
%patch6 -p1 -b .xmldoc
%patch7 -p1 -b .fixmonitor

%build

#needed for correct localstatedir location 
%define _localstatedir %{_var}

COMMON_ARGS="--disable-selinux --with-system-pid-file=%{_var}/run/messagebus.pid --with-system-socket=%{_var}/run/dbus/system_bus_socket --with-session-socket-dir=/tmp --libexecdir=/%{_lib}/dbus-%{lib_api}"

#### Build once with tests to make check
%if %{enable_test}
%configure2_5x $COMMON_ARGS --enable-tests=yes --enable-verbose-mode=yes --enable-asserts=yes  --disable-doxygen-docs --disable-xml-docs

DBUS_VERBOSE=1 %make
make check

#### Clean up and build again 
make clean
%endif 

%configure2_5x $COMMON_ARGS --disable-tests --disable-asserts --enable-doxygen-docs --enable-xml-docs \
%if %enable_verbose
 --enable-verbose-mode=yes
%else 
 --enable-verbose-mode=no
%endif
%make

doxygen Doxyfile

xsltproc -o dbus.devhelp %{SOURCE1} doc/api/xml/index.xml

%check
make check

%install
rm -rf %{buildroot}

%makeinstall_std

# move lib to /, because it might be needed by hotplug script, before
# /usr is mounted
mkdir -p $RPM_BUILD_ROOT/%{_lib} %buildroot%{_var}/lib/dbus
mv $RPM_BUILD_ROOT%{_libdir}/*dbus-1*.so.* $RPM_BUILD_ROOT/%{_lib} 
ln -sf ../../%{_lib}/libdbus-%{lib_api}.so.%{lib_major} $RPM_BUILD_ROOT%{_libdir}/libdbus-%{lib_api}.so

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/X11/xinit.d
cat << EOF > $RPM_BUILD_ROOT%{_sysconfdir}/X11/xinit.d/30dbus
# to be sourced
eval \`/usr/bin/dbus-launch --exit-with-session --sh-syntax\`
EOF
chmod 755 $RPM_BUILD_ROOT%{_sysconfdir}/X11/xinit.d/30dbus

# create directory
mkdir $RPM_BUILD_ROOT%{_datadir}/dbus-%{lib_api}/interfaces

#add devhelp compatible helps
mkdir -p $RPM_BUILD_ROOT%{_datadir}/devhelp/books/dbus
mkdir -p $RPM_BUILD_ROOT%{_datadir}/devhelp/books/dbus/api

cp dbus.devhelp $RPM_BUILD_ROOT%{_datadir}/devhelp/books/dbus
cp doc/dbus-specification.html $RPM_BUILD_ROOT%{_datadir}/devhelp/books/dbus
cp doc/dbus-faq.html $RPM_BUILD_ROOT%{_datadir}/devhelp/books/dbus
cp doc/dbus-tutorial.html $RPM_BUILD_ROOT%{_datadir}/devhelp/books/dbus
cp doc/api/html/* $RPM_BUILD_ROOT%{_datadir}/devhelp/books/dbus/api

#remove unpackaged file
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

%clean
rm -rf %{buildroot}

%pre
%_pre_useradd messagebus / /sbin/nologin
%_pre_groupadd daemon messagebus

%post -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig

%post
if [ "$1" = "1" ]; then 
  /sbin/chkconfig --add messagebus  || /bin/true
fi

%postun
%_postun_userdel messagebus
%_postun_groupdel daemon messagebus

%preun
%_preun_service messagebus

%triggerpostun -- dbus < 0.21-4mdk
/sbin/chkconfig --del messagebus
/sbin/chkconfig --add messagebus

%files
%defattr(-,root,root)

%doc COPYING NEWS

%dir %{_sysconfdir}/dbus-%{lib_api}
%config(noreplace) %{_sysconfdir}/dbus-%{lib_api}/*.conf
%{_sysconfdir}/rc.d/init.d/*
%dir %{_sysconfdir}/dbus-%{lib_api}/system.d
%dir %{_sysconfdir}/dbus-%{lib_api}/session.d
%dir %{_var}/run/dbus
%dir %{_var}/lib/dbus
%dir %{_libdir}/dbus-1.0
%{_bindir}/dbus-daemon
%{_bindir}/dbus-send
%{_bindir}/dbus-cleanup-sockets
%{_bindir}/dbus-uuidgen
%{_mandir}/man*/*
%dir %{_datadir}/dbus-%{lib_api}
%{_datadir}/dbus-%{lib_api}/system-services
%{_datadir}/dbus-%{lib_api}/services
%{_datadir}/dbus-%{lib_api}/interfaces
# See doc/system-activation.txt in source tarball for the rationale
# behind these permissions
%dir /%{_lib}/dbus-%{lib_api}
%attr(4750,root,messagebus) /%{_lib}/dbus-%{lib_api}/dbus-daemon-launch-helper

%files -n %{lib_name}
%defattr(-,root,root)
/%{_lib}/*dbus-%{lib_api}*.so.%{lib_major}*

%files -n %develname
%defattr(-,root,root)
%doc ChangeLog doc/introspect.dtd doc/introspect.xsl doc/system-activation.txt
%{_libdir}/libdbus-%{lib_api}.a
%{_libdir}/libdbus-%{lib_api}.so
%{_libdir}/dbus-1.0/include
%{_libdir}/pkgconfig/dbus-%{lib_api}.pc
%{_includedir}/dbus-1.0
%doc %{_datadir}/devhelp/books/dbus

%files x11
%defattr(-,root,root)
%{_sysconfdir}/X11/xinit.d/*
%{_bindir}/dbus-launch
%{_bindir}/dbus-monitor


%changelog
* Fri Mar 28 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-5mdv2008.1
+ Revision: 190832
- Clean up devel package to not package 47MB of unused documentation

* Thu Mar 27 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-4mdv2008.1
+ Revision: 190617
- Patch7 : fix inotify monitoring, being too agressive
- Add easy way to enable verbose mode in specfile

* Tue Mar 25 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-3mdv2008.1
+ Revision: 189973
- Update patch0 to add soft dependency on network service at startup

* Tue Mar 04 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-2mdv2008.1
+ Revision: 178271
- should-restart is a provides, not a suggests

* Wed Feb 27 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.20-1mdv2008.1
+ Revision: 175910
- Release 1.1.20
- Remove patch7, merged upstream
- no longer restart system bus, rely on should-start = system
- not use rpm-helper for adding service to prevent restarting system bus

* Wed Feb 20 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.4-3mdv2008.1
+ Revision: 173247
-Own some directories (might fix Mdv bug #37567)

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix spacing at top of description

* Wed Feb 06 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.4-2mdv2008.1
+ Revision: 163029
- Patch7 (Fedora): fix dbus not always exiting after X shutdown

* Fri Jan 18 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.4-1mdv2008.1
+ Revision: 154583
- Release 1.1.4
- remove patch7, merged upstream

* Thu Jan 17 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.3-2mdv2008.1
+ Revision: 154280
-Patch 7 (Timo Hoenig): fix inotify backend to not DoS system on upgrade

* Wed Jan 16 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.3-1mdv2008.1
+ Revision: 153648
- Release 1.1.3
- Remove patches 1, 2, 4, 5 (merged upstream)
- Regenerate patch0 (partially merged)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 14 2007 Frederic Crozat <fcrozat@mandriva.com> 1.1.2-4mdv2008.1
+ Revision: 120079
- Disable checks (don't pass on x86-64)
- Clean specfile
- Remove unapproved patch

  + Paulo Andrade <pcpa@mandriva.com.br>
    - This is a "noop" patch. But it can be considered a list of the functions,
      code from X Server uses from dbus (libdbus-1), at a later stage, this library
      can be changed to make available only the public symbols.

* Fri Nov 16 2007 Frederic Crozat <fcrozat@mandriva.com> 1.1.2-3mdv2008.1
+ Revision: 109158
- Disable patch3 (disable fatal warnings on check) for cooker, to detect buggy usage of DBus

* Mon Oct 15 2007 Götz Waschk <waschk@mandriva.org> 1.1.2-2mdv2008.1
+ Revision: 98605
- new devel name

* Mon Oct 15 2007 Frederic Crozat <fcrozat@mandriva.com> 1.1.2-1mdv2008.1
+ Revision: 98570
- Remove patch4, merged upstream
- Patch4 (Fedora): fix arborting (fd.o bug #12430)
- Patch5 (git): fix PIE usage
- Patch6 (Fedora): generate xml doc
- Package devel help in devhelp format

* Tue Sep 11 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-10mdv2008.0
+ Revision: 84492
- Add requires(post) on lib package in main package (Mdv bug #31876)

  + Thierry Vignaud <tvignaud@mandriva.com>
    - replace %%{_datadir}/man by %%{_mandir}!

* Thu Aug 16 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-9mdv2008.0
+ Revision: 64326
- Patch4 (CVS): various bug fixes

* Thu Jul 12 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-8mdv2008.0
+ Revision: 51613
- enable dbus for runlevel 2

* Wed Jul 11 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-7mdv2008.0
+ Revision: 51319
- Enforce dependency of lib package on main package, just in case a program
  is linked to libdbus but doesn't requires dbus package

* Thu Jun 07 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.2-6mdv2008.0
+ Revision: 36905
- rebuild for expat


* Tue Mar 20 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-5mdv2007.1
+ Revision: 147000
- Patch3 (Debian): disable fatal warnings on check by default

* Mon Mar 19 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.0.2-4mdv2007.1
+ Revision: 146591
- bump release
- no need to package big ChangeLog when NEWS is already there

* Tue Jan 23 2007 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-3mdv2007.1
+ Revision: 112518
- Disable assertion and tests for packaged binaries. Build assertions and tests at compile time
  to check if everything is ok

* Wed Dec 13 2006 Frederic Crozat <fcrozat@mandriva.com> 1.0.2-2mdv2007.1
+ Revision: 96425
- Release 1.0.2
  Remove patch3 (merged upstream)

* Thu Nov 23 2006 Frederic Crozat <fcrozat@mandriva.com> 1.0.1-2mdv2007.1
+ Revision: 86697
- Force rebuild
- Rebuild
- Release 1.0.1
- Patch1: add inotify support
- Patch2: fix config file creation notification with dnotify
- Patch3 (CVS): fix assertion

* Fri Nov 10 2006 Götz Waschk <waschk@mandriva.org> 1.0.0-1mdv2007.0
+ Revision: 80522
- new version

* Sat Nov 04 2006 Götz Waschk <waschk@mandriva.org> 0.95-1mdv2007.1
+ Revision: 76480
- new version
- drop patch 1
- drop uuidgen workaround
- create /var/lib/dbus directory

* Sun Oct 29 2006 Götz Waschk <waschk@mandriva.org> 0.94-9mdv2007.1
+ Revision: 73643
- rebuild
- add fix for upstream bug 8780

* Wed Oct 25 2006 Götz Waschk <waschk@mandriva.org> 0.94-7mdv2007.0
+ Revision: 72405
- bot rebuild
- fix permissions of the machine-id file
- call dbus-uuidgen in postinstallation (bug #26723)

* Wed Oct 18 2006 Götz Waschk <waschk@mandriva.org> 0.94-4mdv2007.0
+ Revision: 65799
- rename system socket (gnome bug #362601)

* Tue Oct 17 2006 Götz Waschk <waschk@mandriva.org> 0.94-3mdv2006.0
+ Revision: 65533
- fix buildrequires
- fix buildrequires
  update file list
- Import dbus

* Tue Oct 17 2006 Gtz Waschk <waschk@mandriva.org> 0.94-1mdv2007.1
- update file list
- drop patches 1,2
- New version 0.94

* Fri Sep 01 2006 Gtz Waschk <waschk@mandriva.org> 0.92-6mdv2007.0
- fix buildrequires

* Wed Aug 30 2006 Frederic Crozat <fcrozat@mandriva.com> 0.92-5mdv2007.0
- Enable asserts and verbose mode, since dbus isn't 1.0 yet (J5)

* Wed Aug 30 2006 Frederic Crozat <fcrozat@mandriva.com> 0.92-4mdv2007.0
- Patch1 (CVS): fix vtable crash
- Patch2: trap SIGTERM to be able to kill session bus (Mdv bug #22143)

* Fri Aug 25 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.92-3
- fix xinit.d script to use sh-syntax, since it is always sourced by /bin/sh

* Fri Aug 25 2006 Olivier Blin <blino@mandriva.com> 0.92-2mdv2007.0
- prefix the xinit.d script with a 2 digit number
- the xinit.d script is not a config file

* Tue Aug 22 2006 Frederic Crozat <fcrozat@mandriva.com> 0.92-1mdv2007.0
- Release 0.92
- remove patch1 (merged upstream)

* Fri Aug 18 2006 Frederic Crozat <fcrozat@mandriva.com> 0.91-5mdv2007.0
- Patch1 (CVS): fix threads deadlock

* Thu Aug 10 2006 Gtz Waschk <waschk@mandriva.org> 0.91-4mdv2007.0
- fix the patch again

* Thu Aug 10 2006 Gtz Waschk <waschk@mandriva.org> 0.91-3mdv2007.0
- update patch with a fix for bug #21935

* Tue Aug 08 2006 Gtz Waschk <waschk@mandriva.org> 0.91-2mdv2007.0
- fix buildrequires

* Wed Jul 19 2006 Frederic Crozat <fcrozat@mandriva.com> 0.90-1mdv2007.0
- Release 0.90
- Remove bindings (packaged seperately now)
- Add conflicts to ease upgrade from 2006.0

* Wed Jul 19 2006 Gtz Waschk <waschk@mandriva.org> 0.62-5mdv2007.0
- remove some useless static libs
- fix postun script of the sharp package

* Thu Jun 22 2006 Gtz Waschk <waschk@mandriva.org> 0.62-4mdv2007.0
- don't depend on kdelibs

* Thu Jun 15 2006 Frederic Crozat <fcrozat@mandriva.com> 0.62-3mdv2007.0
- Regenerate patch0 and merge patch1 in it
- add strict rules for lib major in file list
- fix localstatedir location (Mdv bug #23107)

* Wed Jun 14 2006 Frederic Crozat <fcrozat@mandriva.com> 0.62-2mdv2007.0
- Rebuild with correct major for qt

* Tue Jun 13 2006 Frederic Crozat <fcrozat@mandriva.com> 0.62-1mdv2007.0
- Release 0.62
- Remove patch2 (merged upstream)

* Wed May 10 2006 Gtz Waschk <waschk@mandriva.org> 0.61-5mdk
- fix dbus-sharp pkgconfig file for x86_64

* Fri May 05 2006 Gtz Waschk <waschk@mandriva.org> 0.61-4mdk
- fix x86_64 build

* Tue Apr 25 2006 Gtz Waschk <waschk@mandriva.org> 0.61-3mdk
- fix postun of the sharp package

* Sat Apr 22 2006 Gtz Waschk <waschk@mandriva.org> 0.61-2mdk
- merge sharp bindings

* Tue Feb 28 2006 Frederic Crozat <fcrozat@mandriva.com> 0.61-1mdk
- Release 0.61
- Remove patch2, no longer needed
- Patch2: allow to disable QT4 binding

* Thu Jan 26 2006 Michael Scherer <misc@mandriva.org> 0.60-2mdk
- fix missing Requires on python binding ( thanks Christiaan Welvaart )

* Wed Jan 25 2006 Frederic Crozat <fcrozat@mandriva.com> 0.60-1mdk
- Release 0.60
- Regenerate patch2
- Remove patch3 (merged upstream)

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 0.50-7mdk
- convert parallel init to LSB

* Fri Jan 06 2006 Oden Eriksson <oeriksson@mandriva.com> 0.50-6mdk
- drop selinux support

* Thu Jan 05 2006 Frederic Crozat <fcrozat@mandriva.com> 0.50-5mdk
- use mkrel
- fix buildrequires

* Mon Jan 02 2006 Olivier Blin <oblin@mandriva.com> 0.50-4mdk
- Patch1: parallel init support

* Tue Dec 27 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.50-3mdk
- patch3: use $(LIBTOOL) in Makefile.am
- fix URL

* Mon Nov 07 2005 Frederic Crozat <fcrozat@mandriva.com> 0.50-2mdk
- Enforce sub package dependency (found by till)

* Wed Oct 26 2005 Frederic Crozat <fcrozat@mandriva.com> 0.50-1mdk
- Release 0.50
- Remove patches 3, 5 (merged upstream)

* Tue Sep 13 2005 Gtz Waschk <waschk@mandriva.org> 0.23.4-5mdk
- move qt headers to the right package
- replace prereq

* Fri Sep 02 2005 Götz Waschk <waschk@mandriva.org> 0.23.4-4mdk
- rebuild to remove glitz dep

* Thu Aug 18 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.23.4-3mdk
- enable possibility to build without qt/kde stuff

* Sat Apr 30 2005 Gtz Waschk <waschk@mandriva.org> 0.23.4-2mdk
- add provides to the libdbus-glib package

* Sat Apr 23 2005 Gtz Waschk <waschk@mandriva.org> 0.23.4-1mdk
- drop patch 6
- New release 0.23.4

* Tue Mar 01 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23.2-2mdk 
- Patch6 (CVS): fix python binding

* Wed Feb 23 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23.2-1mdk 
- Release 0.23.2
- Remove patch4 (merged upstream)

* Wed Feb 16 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23.1-1mdk 
- Release 0.23.1
- Patch5 (CVS): fix crash when setting group policy

* Wed Feb 16 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23-5mdk 
- Move dbus xinit launcher in dbus-x11 package (Mdk bug #13075)

* Wed Feb 09 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.23-4mdk
- let devel symlinks stay in standard libdir

* Tue Feb 08 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.23-3mdk 
- Patch3 (Fedora): allow uid/gid to identify user/group
- Patch4 (Fedora): restrict connection to user session bus to owner or root

* Fri Jan 21 2005 Gtz Waschk <waschk@linux-mandrake.com> 0.23-2mdk
- add missing directory

* Thu Jan 20 2005 Gtz Waschk <waschk@linux-mandrake.com> 0.23-1mdk
- drop patches 1,3
- update source URL
- New release 0.23

* Wed Dec 08 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.22-7mdk 
- automatically start dbus when starting a X11 session

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 0.22-6mdk
- Rebuild for new python

* Mon Nov 15 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.22-5mdk
- add BuildRequires: kdelibs-devel

* Fri Nov 12 2004 Gtz Waschk <waschk@linux-mandrake.com> 0.22-4mdk
- create Qt development package

* Fri Oct 01 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.22-3mdk
- explicitly disable Mono bindings

* Fri Oct 01 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.22-2mdk
- fix detection of moc path
- merge in RH in64 fix for python bindings

* Sat Aug 14 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.22-1mdk
- Release 0.22
- Remove patch1 (merged upstream)
- enable libtoolize 
- Patch1 (Fedora): add console policy

* Tue Aug 10 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.21-4mdk
- Update patch 20 to change start order (should fix bluetooth daemon start)

* Thu Jun 17 2004 Stew Benedict <sbenedict@mandrakesoft.com> 0.21-3mdk
- add docs to -devel, dbus-monitor fixes from cvs (patch1)

* Sat Jun 05 2004 Laurent Montel <lmontel@mandrakesoft.com> 0.21-2mdk
- Rebuild

* Tue Apr 20 2004 Gtz Waschk <waschk@linux-mandrake.com> 0.21-1mdk
- fix qt build
- drop merged patch 1
- fix URL
- new version

